@@ -12,6 +12,7 @@ from .dynamo_db_stream_event import DynamoDBStreamEvent
 from .event_bridge_event import EventBridgeEvent
 from .event_source import event_source
 from .kinesis_stream_event import KinesisStreamEvent
+from .lambda_function_url_event import LambdaFunctionUrlEvent
 from .s3_event import S3Event
 from .ses_event import SESEvent
 from .sns_event import SNSEvent
@@ -28,6 +29,7 @@ __all__ = [
     "DynamoDBStreamEvent",
     "EventBridgeEvent",
     "KinesisStreamEvent",
+    "LambdaFunctionUrlEvent",
     "S3Event",
     "SESEvent",
     "SNSEvent",
